from justhacking import letsbegin

def main():
  letsbegin()
